@@ -25,10 +25,10 @@ theme_set(theme_bw())
 source(here("inst", "sbc", "sbc_tools.R"))
 
 knitr::opts_chunk$set(
-  fig.width = 1.62*4,
+  fig.width = 1.62 * 4,
   fig.height = 4,
-  cache=FALSE,
-  echo=FALSE
+  cache = FALSE,
+  echo = FALSE
 )
 #'
 #' This report documents the results of a simulation based calibration
@@ -36,7 +36,7 @@ knitr::opts_chunk$set(
 #'
 #' The calibration data presented here has been generated at and with
 #' the `OncoBayes` git version as:
-cat(readLines(here("inst", "sbc", "calibration.md5")), sep="\n")
+cat(readLines(here("inst", "sbc", "calibration.md5")), sep = "\n")
 #'
 #' The MD5 hash of the calibration data file presented here must match
 #' the above listed MD5:
@@ -88,10 +88,15 @@ md5sum(here("inst", "sbc", "calibration.rds"))
 
 calibration <- readRDS(here("inst", "sbc", "calibration.rds"))
 
+have_raw <- file.exists(here("inst", "sbc", "calibration_data.rds"))
+if (have_raw) {
+  calibration_raw <- readRDS(here("inst", "sbc", "calibration_data.rds"))
+}
 
 include_plots <- TRUE
-if("params" %in% ls())
-    include_plots <- params$include_plots
+if ("params" %in% ls()) {
+  include_plots <- params$include_plots
+}
 
 # The summary function we use here scales down the $L+1=1024$ bins to
 # smaller number of rank bins. This improves the number of counts
@@ -101,48 +106,47 @@ if("params" %in% ls())
 # of $2$ can be used to scale down the number of bins.
 
 plot_binned <- function(cal_df) {
+  pl <- NULL
 
-    pl <- NULL
+  if (!include_plots) {
+    return(pl)
+  }
 
-    if(!include_plots)
-        return(pl)
+  if (!all(cal_df$count == 0)) {
+    S <- calibration$S
+    B <- calibration$B
 
-    if(!all(cal_df$count == 0)) {
+    c95 <- qbinom(c(0.025, 0.5, 0.975), S, 1 / B)
 
-        S <- calibration$S
-        B <- calibration$B
+    dd <- cal_df %>%
+      arrange(param, bin) %>%
+      group_by(param) %>%
+      mutate(ecdf = cumsum(count) / S, ecdf_ref = (bin + 1) / B) %>%
+      filter(!all(ecdf == 0))
 
-        c95 <- qbinom(c(0.025, 0.5, 0.975), S, 1 / B)
-
-        dd <- cal_df %>%
-            arrange(param, bin) %>%
-                group_by(param) %>%
-                    mutate(ecdf = cumsum(count) / S, ecdf_ref = (bin + 1) / B) %>%
-                        filter(!all(ecdf == 0))
-
-        nparam <- length(unique(dd$param))
-        if(unique(dd$partype) %in% c("mu_eta", "tau_eta")){
-            nc <- nparam
-        } else{
-            nc <- 2
-        }
-
-        nr <- max(1, ceiling(nparam / nc))
-
-        pl <- list()
-        pl[["hist"]] <- ggplot(dd, aes(bin, count)) +
-            facet_wrap(~ param, nrow = nr, ncol = nc) +
-                geom_col() +
-                    geom_hline(yintercept=c95[c(1,3)], linetype=I(2)) +
-                        geom_hline(yintercept=c95[c(2)], linetype=I(3))
-        pl[["ecdf_diff"]] <- ggplot(dd, aes(bin, ecdf-ecdf_ref)) +
-            facet_wrap(~ param, nrow = nr, ncol = nc) +
-                geom_step() +
-                    geom_hline(yintercept=0, linetype=I(3))
-        pl
+    nparam <- length(unique(dd$param))
+    if (unique(dd$partype) %in% c("mu_eta", "tau_eta")) {
+      nc <- nparam
+    } else {
+      nc <- 2
     }
 
-    return(pl)
+    nr <- max(1, ceiling(nparam / nc))
+
+    pl <- list()
+    pl[["hist"]] <- ggplot(dd, aes(bin, count)) +
+      facet_wrap(~param, nrow = nr, ncol = nc) +
+      geom_col() +
+      geom_hline(yintercept = c95[c(1, 3)], linetype = I(2)) +
+      geom_hline(yintercept = c95[c(2)], linetype = I(3))
+    pl[["ecdf_diff"]] <- ggplot(dd, aes(bin, ecdf - ecdf_ref)) +
+      facet_wrap(~param, nrow = nr, ncol = nc) +
+      geom_step() +
+      geom_hline(yintercept = 0, linetype = I(3))
+    pl
+  }
+
+  return(pl)
 }
 
 
@@ -150,9 +154,11 @@ B <- calibration$B
 S <- calibration$S
 
 bins_all <- calibration$data %>%
-  tidyr::gather(key = "param", value = "count", - data_scenario, -bin) %>%
-  mutate(partype = sapply(strsplit(param, "[[]"), '[', 1),
-         group = interaction(data_scenario, partype))
+  tidyr::gather(key = "param", value = "count", -data_scenario, -bin) %>%
+  mutate(
+    partype = sapply(strsplit(param, "[[]"), "[", 1),
+    group = interaction(data_scenario, partype)
+  )
 
 
 cal_split <- split(bins_all, bins_all$group)
@@ -164,20 +170,21 @@ pl_split <- lapply(cal_split, function(cal_df) plot_binned(cal_df))
 #'
 #' ## Sampler Diagnostics Overview
 #'
-kable(calibration$sampler_diagnostics, digits=3)
+kable(calibration$sampler_diagnostics, digits = 3)
 
 
 #'
-#+ include=include_plots, eval=include_plots, fig.width=8,fig.height=6
-calibration$raw %>%
-    select(starts_with("min_"), "max_Rhat", starts_with("lp_"), "data_scenario") %>%
-    pivot_longer(!data_scenario, names_to="metric") %>%
-    ggplot(aes(value)) +
-    facet_grid(data_scenario~metric, scales="free_x") +
-    geom_histogram(bins=60) + xlab(NULL) +
-    scale_x_log10() +
-    theme(axis.text.x = element_text(angle = 60, vjust = 1, hjust=1)) +
-    ggtitle("Sampler diagnostics")
+#+ include=include_plots&have_raw, eval=include_plots&have_raw, fig.width=8,fig.height=6
+calibration_raw %>%
+  select(starts_with("min_"), "max_Rhat", starts_with("lp_"), "data_scenario") %>%
+  pivot_longer(!data_scenario, names_to = "metric") %>%
+  ggplot(aes(value)) +
+  facet_grid(data_scenario ~ metric, scales = "free_x") +
+  geom_histogram(bins = 60) +
+  xlab(NULL) +
+  scale_x_log10() +
+  theme(axis.text.x = element_text(angle = 60, vjust = 1, hjust = 1)) +
+  ggtitle("Sampler diagnostics")
 
 #'
 #' Large Rhat is defined as exceeding $1.1$.
@@ -185,66 +192,75 @@ calibration$raw %>%
 #' ## Sampler Adaptation & Performance Overview
 #'
 #'
-sampler_performance <- calibration$raw %>%
-    select("time.running", starts_with("lp_"), "stepsize", "accept_stat", "data_scenario") %>%
-    mutate(lp_ess_bulk_speed=lp_ess_bulk / time.running, lp_ess_tail_speed=lp_ess_tail / time.running) %>%
-    select("data_scenario", "stepsize", "accept_stat", ends_with("_speed"))
+#+ include=include_plots&have_raw, eval=include_plots&have_raw
+sampler_performance <- calibration_raw %>%
+  select("time.running", starts_with("lp_"), "stepsize", "accept_stat", "data_scenario") %>%
+  mutate(lp_ess_bulk_speed = lp_ess_bulk / time.running, lp_ess_tail_speed = lp_ess_tail / time.running) %>%
+  select("data_scenario", "stepsize", "accept_stat", ends_with("_speed"))
 
-sampler_performance %>% group_by(data_scenario) %>%
-    summarize(across(where(is.numeric), list(mean=mean, sd=sd)), N=n()) %>%
-    relocate(data_scenario, N) %>%
-    kable(digits=3)
+sampler_performance %>%
+  group_by(data_scenario) %>%
+  summarize(across(where(is.numeric), list(mean = mean, sd = sd)), N = n()) %>%
+  relocate(data_scenario, N) %>%
+  kable(digits = 3)
 
 #'
 #' ESS speed is in units of ESS per second.
 #'
 
-#+ include=include_plots, eval=include_plots, fig.width=8,fig.height=6
+#+ include=include_plots&have_raw, eval=include_plots&have_raw, fig.width=8,fig.height=6
 sampler_performance %>%
-    pivot_longer(!data_scenario, names_to="metric") %>%
-    mutate(metric=factor(metric, c("accept_stat", "stepsize", "lp_ess_bulk_speed", "lp_ess_tail_speed"))) %>%
-    ggplot(aes(value)) +
-    facet_grid(data_scenario~metric, scales="free_x") +
-    geom_histogram(bins=60) + xlab(NULL) +
-    scale_x_log10() +
-    theme(axis.text.x = element_text(angle = 60, vjust = 1, hjust=1)) +
-    ggtitle("Sampler adaptation & performance")
+  pivot_longer(!data_scenario, names_to = "metric") %>%
+  mutate(metric = factor(metric, c("accept_stat", "stepsize", "lp_ess_bulk_speed", "lp_ess_tail_speed"))) %>%
+  ggplot(aes(value)) +
+  facet_grid(data_scenario ~ metric, scales = "free_x") +
+  geom_histogram(bins = 60) +
+  xlab(NULL) +
+  scale_x_log10() +
+  theme(axis.text.x = element_text(angle = 60, vjust = 1, hjust = 1)) +
+  ggtitle("Sampler adaptation & performance")
 
 #'
 #'
-chisq  <- bins_all %>%
+chisq <- bins_all %>%
   arrange(data_scenario, partype, param, bin) %>%
   group_by(data_scenario, partype, param) %>%
   mutate(allna = all(count == 0)) %>%
   filter(!allna) %>%
-  do(tidy(chisq.test(.$count))[,c(1,3,2)] ) %>%
+  do(tidy(chisq.test(.$count))[, c(1, 3, 2)]) %>%
   rename(df = parameter) %>%
   ungroup()
 
 #'
-#' ## $\chi^2$ Statistic, Model 1: Single-agent logistic regression
+#' ## $\chi^2$ Statistic: Single-agent logistic regression, stratified
 #'
 
-kable(chisq %>% filter(data_scenario== "log2bayes_EXNEX") %>% select(-data_scenario, -partype), digits=3)
+kable(chisq %>% filter(data_scenario == "log2bayes_EX") %>% select(-data_scenario, -partype), digits = 3)
 
 #'
-#' ## $\chi^2$ Statistic, Model 2: Double combination, fully exchangeable
+#' ## $\chi^2$ Statistic: Single-agent logistic regression, EXchangeable/NonEXchangeable
+#'
+
+kable(chisq %>% filter(data_scenario == "log2bayes_EXNEX") %>% select(-data_scenario, -partype), digits = 3)
+
+#'
+#' ## $\chi^2$ Statistic: Double combination, fully exchangeable, stratified
 #'
 
 
-kable(chisq %>% filter(data_scenario == "combo2_EX") %>% select(-data_scenario, -partype), digits=3)
+kable(chisq %>% filter(data_scenario == "combo2_EX") %>% select(-data_scenario, -partype), digits = 3)
 
 #'
-#' ## $\chi^2$ Statistic, Model 3: Double combination, EXchangeable/NonEXchangeable model
+#' ## $\chi^2$ Statistic: Double combination, EXchangeable/NonEXchangeable
 #'
 
-kable(chisq %>% filter(data_scenario == "combo2_EXNEX") %>% select(-data_scenario, -partype), digits=3)
+kable(chisq %>% filter(data_scenario == "combo2_EXNEX") %>% select(-data_scenario, -partype), digits = 3)
 
 #'
-#' ## $\chi^2$ Statistic, Model 4: Triple combination, EX/NEX model
+#' ## $\chi^2$ Statistic: Triple combination, EXchangeable/NonEXchangeable
 #'
 
-kable(chisq %>% filter(data_scenario == "combo3_EXNEX") %>% select(-data_scenario, -partype), digits=3)
+kable(chisq %>% filter(data_scenario == "combo3_EXNEX") %>% select(-data_scenario, -partype), digits = 3)
 
 #+ results="asis", include=include_plots, eval=include_plots
 spin_child("sbc_report_plots.R")
@@ -253,4 +269,3 @@ spin_child("sbc_report_plots.R")
 #' ## Session Info
 #'
 sessionInfo()
-
